==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24InvocationMouseMotionHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$InvocationMouseMotionHandler

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d67db9e2569cc609 javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler

// header file dependencies
// @dep_header java_awt_event_MouseMotionAdapter

#include "java/awt/event/MouseMotionAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method_info$mouseDragged$3079e58fafa0fefe;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24InvocationMouseMotionHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$InvocationMouseMotionHandler

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d67db9e2569cc609 javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler

// header file dependencies
// @dep_header java_awt_event_MouseMotionAdapter

#include "java/awt/event/MouseMotionAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$method_info$mouseDragged$3079e58fafa0fefe;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationMouseMotionHandler_H_ */
